Module create_column

Module create_column 

Implementation of SQL CREATE COLUMN statements

Structs

CreateColumnPostgresDatapostgres
Representation of the data of the creation of a column for the mysql dialect
CreateColumnSQLiteDatasqlite
Representation of the data of the creation of a column for the sqlite dialect
SQLAnnotation
Representation of an annotation

Enums

CreateColumnImpl
Representation of the different implementations of the CreateColumn trait.
PostgresType
Return type of postgres_type

Traits

CreateColumn
Trait representing the create table builder.

Functions

postgres_type
Converts a DbType into the associated postgres type.
sqlite_type
Converts a DbType into the associated sqlite type.