Value

Enum Value 

pub enum Value<'a> {
Show 49 variants Null(NullType), Ident(&'a str), Column { table_name: Option<&'a str>, column_name: &'a str, }, Choice(&'a str), String(&'a str), I64(i64), I32(i32), I16(i16), Bool(bool), F64(f64), F32(f32), Binary(&'a [u8]), ChronoNaiveTime(NaiveTime), ChronoNaiveDate(NaiveDate), ChronoNaiveDateTime(NaiveDateTime), ChronoDateTime(DateTime<Utc>), TimeDate(Date), TimeTime(Time), TimeOffsetDateTime(OffsetDateTime), TimePrimitiveDateTime(PrimitiveDateTime), Uuid(Uuid), UuidHyphenated(Uuid), UuidSimple(Uuid), JsonValue(&'a Value), MacAddress(MacAddress), IpNetwork(IpNetwork), BitVec(&'a BitVec), ArrayNull(NullType), ArrayString(&'a [&'a str]), ArrayI64(&'a [i64]), ArrayI32(&'a [i32]), ArrayI16(&'a [i16]), ArrayBool(&'a [bool]), ArrayF64(&'a [f64]), ArrayF32(&'a [f32]), ArrayBinary(&'a [&'a [u8]]), ArrayChronoNaiveTime(&'a [NaiveTime]), ArrayChronoNaiveDate(&'a [NaiveDate]), ArrayChronoNaiveDateTime(&'a [NaiveDateTime]), ArrayChronoDateTime(&'a [DateTime<Utc>]), ArrayTimeDate(&'a [Date]), ArrayTimeTime(&'a [Time]), ArrayTimeOffsetDateTime(&'a [OffsetDateTime]), ArrayTimePrimitiveDateTime(&'a [PrimitiveDateTime]), ArrayUuid(&'a [Uuid]), ArrayJsonValue(&'a [&'a Value]), ArrayMacAddress(&'a [MacAddress]), ArrayIpNetwork(&'a [IpNetwork]), ArrayBitVec(&'a [&'a BitVec]),
}
This enum represents a value

Variants



Null(NullType)

null representation



Ident(&'a str)

👎Deprecated:

Is this still used?

Representation of an identifier, e.g. a column. This variant will not be escaped, so do not pass unchecked data to it.



Column

Representation of a column name with an optional table name

Fields

table_name: Option<&'a str>

Name of the table

column_name: &'a str

Name of the column



Choice(&'a str)

Representation of choices



String(&'a str)

String representation



I64(i64)

i64 representation



I32(i32)

i32 representation



I16(i16)

i16 representation



Bool(bool)

Bool representation



F64(f64)

f64 representation



F32(f32)

f32 representation



Binary(&'a [u8])

binary representation



ChronoNaiveTime(NaiveTime)

chrono’s Naive Time representation



ChronoNaiveDate(NaiveDate)

chrono’s Naive Date representation



ChronoNaiveDateTime(NaiveDateTime)

chrono’s Naive DateTime representation



ChronoDateTime(DateTime<Utc>)

chrono’s Timezone aware datetime



TimeDate(Date)

time’s date representation



TimeTime(Time)

time’s time representation



TimeOffsetDateTime(OffsetDateTime)

time’s offset datetime representation



TimePrimitiveDateTime(PrimitiveDateTime)

time’s primitive datetime representation



Uuid(Uuid)

Uuid representation



UuidHyphenated(Uuid)

👎Deprecated:

Was this ever used?

Uuid in hyphenated representation



UuidSimple(Uuid)

👎Deprecated:

Was this ever used?

Uuid in simple text representation



JsonValue(&'a Value)

serde_json’s Value representation



MacAddress(MacAddress)

Available on crate feature postgres-only only.

Mac address representation



IpNetwork(IpNetwork)

Available on crate feature postgres-only only.

IP network presentation



BitVec(&'a BitVec)

Available on crate feature postgres-only only.

Bit vec representation



ArrayNull(NullType)

Available on crate feature postgres-only only.

null representation



ArrayString(&'a [&'a str])

Available on crate feature postgres-only only.

String representation



ArrayI64(&'a [i64])

Available on crate feature postgres-only only.

i64 representation



ArrayI32(&'a [i32])

Available on crate feature postgres-only only.

i32 representation



ArrayI16(&'a [i16])

Available on crate feature postgres-only only.

i16 representation



ArrayBool(&'a [bool])

Available on crate feature postgres-only only.

Bool representation



ArrayF64(&'a [f64])

Available on crate feature postgres-only only.

f64 representation



ArrayF32(&'a [f32])

Available on crate feature postgres-only only.

f32 representation



ArrayBinary(&'a [&'a [u8]])

Available on crate feature postgres-only only.

binary representation



ArrayChronoNaiveTime(&'a [NaiveTime])

Available on crate feature postgres-only only.

chrono’s Naive Time representation



ArrayChronoNaiveDate(&'a [NaiveDate])

Available on crate feature postgres-only only.

chrono’s Naive Date representation



ArrayChronoNaiveDateTime(&'a [NaiveDateTime])

Available on crate feature postgres-only only.

chrono’s Naive DateTime representation



ArrayChronoDateTime(&'a [DateTime<Utc>])

Available on crate feature postgres-only only.

chrono’s Timezone aware datetime



ArrayTimeDate(&'a [Date])

Available on crate feature postgres-only only.

time’s date representation



ArrayTimeTime(&'a [Time])

Available on crate feature postgres-only only.

time’s time representation



ArrayTimeOffsetDateTime(&'a [OffsetDateTime])

Available on crate feature postgres-only only.

time’s offset datetime representation



ArrayTimePrimitiveDateTime(&'a [PrimitiveDateTime])

Available on crate feature postgres-only only.

time’s primitive datetime representation



ArrayUuid(&'a [Uuid])

Available on crate feature postgres-only only.

Uuid representation



ArrayJsonValue(&'a [&'a Value])

Available on crate feature postgres-only only.

serde_json’s Value representation



ArrayMacAddress(&'a [MacAddress])

Available on crate feature postgres-only only.

Mac address representation



ArrayIpNetwork(&'a [IpNetwork])

Available on crate feature postgres-only only.

IP network presentation



ArrayBitVec(&'a [&'a BitVec])

Available on crate feature postgres-only only.

Bit vec representation