pub enum Value<'a> {
Show 49 variants
Null(NullType),
Ident(&'a str),
Column {
table_name: Option<&'a str>,
column_name: &'a str,
},
Choice(&'a str),
String(&'a str),
I64(i64),
I32(i32),
I16(i16),
Bool(bool),
F64(f64),
F32(f32),
Binary(&'a [u8]),
ChronoNaiveTime(NaiveTime),
ChronoNaiveDate(NaiveDate),
ChronoNaiveDateTime(NaiveDateTime),
ChronoDateTime(DateTime<Utc>),
TimeDate(Date),
TimeTime(Time),
TimeOffsetDateTime(OffsetDateTime),
TimePrimitiveDateTime(PrimitiveDateTime),
Uuid(Uuid),
UuidHyphenated(Uuid),
UuidSimple(Uuid),
JsonValue(&'a Value),
MacAddress(MacAddress),
IpNetwork(IpNetwork),
BitVec(&'a BitVec),
ArrayNull(NullType),
ArrayString(&'a [&'a str]),
ArrayI64(&'a [i64]),
ArrayI32(&'a [i32]),
ArrayI16(&'a [i16]),
ArrayBool(&'a [bool]),
ArrayF64(&'a [f64]),
ArrayF32(&'a [f32]),
ArrayBinary(&'a [&'a [u8]]),
ArrayChronoNaiveTime(&'a [NaiveTime]),
ArrayChronoNaiveDate(&'a [NaiveDate]),
ArrayChronoNaiveDateTime(&'a [NaiveDateTime]),
ArrayChronoDateTime(&'a [DateTime<Utc>]),
ArrayTimeDate(&'a [Date]),
ArrayTimeTime(&'a [Time]),
ArrayTimeOffsetDateTime(&'a [OffsetDateTime]),
ArrayTimePrimitiveDateTime(&'a [PrimitiveDateTime]),
ArrayUuid(&'a [Uuid]),
ArrayJsonValue(&'a [&'a Value]),
ArrayMacAddress(&'a [MacAddress]),
ArrayIpNetwork(&'a [IpNetwork]),
ArrayBitVec(&'a [&'a BitVec]),
}Expand description
This enum represents a value
Variants
Null(NullType)
null representation
Ident(&'a str)
Is this still used?
Representation of an identifier, e.g. a column. This variant will not be escaped, so do not pass unchecked data to it.
Column
Representation of a column name with an optional table name
Choice(&'a str)
Representation of choices
String(&'a str)
String representation
I64(i64)
i64 representation
I32(i32)
i32 representation
I16(i16)
i16 representation
Bool(bool)
Bool representation
F64(f64)
f64 representation
F32(f32)
f32 representation
Binary(&'a [u8])
binary representation
ChronoNaiveTime(NaiveTime)
chrono’s Naive Time representation
ChronoNaiveDate(NaiveDate)
chrono’s Naive Date representation
ChronoNaiveDateTime(NaiveDateTime)
chrono’s Naive DateTime representation
ChronoDateTime(DateTime<Utc>)
chrono’s Timezone aware datetime
TimeDate(Date)
time’s date representation
TimeTime(Time)
time’s time representation
TimeOffsetDateTime(OffsetDateTime)
time’s offset datetime representation
TimePrimitiveDateTime(PrimitiveDateTime)
time’s primitive datetime representation
Uuid(Uuid)
Uuid representation
UuidHyphenated(Uuid)
Was this ever used?
Uuid in hyphenated representation
UuidSimple(Uuid)
Was this ever used?
Uuid in simple text representation
JsonValue(&'a Value)
serde_json’s Value representation
MacAddress(MacAddress)
postgres-only only.Mac address representation
IpNetwork(IpNetwork)
postgres-only only.IP network presentation
BitVec(&'a BitVec)
postgres-only only.Bit vec representation
ArrayNull(NullType)
postgres-only only.null representation
ArrayString(&'a [&'a str])
postgres-only only.String representation
ArrayI64(&'a [i64])
postgres-only only.i64 representation
ArrayI32(&'a [i32])
postgres-only only.i32 representation
ArrayI16(&'a [i16])
postgres-only only.i16 representation
ArrayBool(&'a [bool])
postgres-only only.Bool representation
ArrayF64(&'a [f64])
postgres-only only.f64 representation
ArrayF32(&'a [f32])
postgres-only only.f32 representation
ArrayBinary(&'a [&'a [u8]])
postgres-only only.binary representation
ArrayChronoNaiveTime(&'a [NaiveTime])
postgres-only only.chrono’s Naive Time representation
ArrayChronoNaiveDate(&'a [NaiveDate])
postgres-only only.chrono’s Naive Date representation
ArrayChronoNaiveDateTime(&'a [NaiveDateTime])
postgres-only only.chrono’s Naive DateTime representation
ArrayChronoDateTime(&'a [DateTime<Utc>])
postgres-only only.chrono’s Timezone aware datetime
ArrayTimeDate(&'a [Date])
postgres-only only.time’s date representation
ArrayTimeTime(&'a [Time])
postgres-only only.time’s time representation
ArrayTimeOffsetDateTime(&'a [OffsetDateTime])
postgres-only only.time’s offset datetime representation
ArrayTimePrimitiveDateTime(&'a [PrimitiveDateTime])
postgres-only only.time’s primitive datetime representation
ArrayUuid(&'a [Uuid])
postgres-only only.Uuid representation
ArrayJsonValue(&'a [&'a Value])
postgres-only only.serde_json’s Value representation
ArrayMacAddress(&'a [MacAddress])
postgres-only only.Mac address representation
ArrayIpNetwork(&'a [IpNetwork])
postgres-only only.IP network presentation
ArrayBitVec(&'a [&'a BitVec])
postgres-only only.Bit vec representation